/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: JavaxAnnotationManagedBeanVisitor.java 6305 2012-11-19 13:04:05Z albertil $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl.configurator.visitor.clazz;

import org.ow2.util.ee.metadata.common.api.ICommonClassMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonFieldMetadata;
import org.ow2.util.ee.metadata.common.api.ICommonMethodMetadata;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.AnnotationType;
import org.ow2.util.ee.metadata.common.impl.configurator.visitor.ObjectAnnotationVisitor;

/**
 * @author Loic Albertin
 */
public class JavaxAnnotationManagedBeanVisitor<
        C extends ICommonClassMetadata<C, M, F>,
        M extends ICommonMethodMetadata<C, M, F>,
        F extends ICommonFieldMetadata<C, M, F>> extends ObjectAnnotationVisitor<C, String> implements AnnotationType {
    /**
     * Type of annotation.
     */
    public static final String TYPE = "Ljavax/annotation/ManagedBean;";

    /**
     * Constructor.
     *
     * @param annotationMetadata linked to a metadata.
     */
    public JavaxAnnotationManagedBeanVisitor(final C annotationMetadata) {
        super(annotationMetadata);
    }

    @Override
    public void visitEnd() {
        String value = getValue();
        if (value == null || value.equals("")) {
            // Set the class name if there is no value
            value = getAnnotationMetadata().getJClass().getName();
            if (value.contains("/")) {
                value = value.substring(value.lastIndexOf("/") + 1);
            }
        }
       getAnnotationMetadata().setManagedBeanName(value);
    }

    public String getType() {
        return JavaxAnnotationManagedBeanVisitor.TYPE;
    }
}
