/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AbsResourceGroup.java 6174 2012-02-16 14:33:48Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl.xml.struct;

import java.util.ArrayList;
import java.util.List;

import org.ow2.util.ee.metadata.common.api.xml.struct.IInjectionTarget;
import org.ow2.util.ee.metadata.common.api.xml.struct.IResourceGroup;

/**
 * Defines the java EE resourceGroup type.<br>
 * It defines mapped-name and injection-target
 * @author Florent Benoit
 */
public class AbsResourceGroup implements IResourceGroup {


    /**
     * Serial version UID.
     */
    private static final long serialVersionUID = 2664044278558086531L;

    /**
     * Injection target (if any).
     */
    private List<IInjectionTarget> injectionTargetList = null;

    /**
     * Default constructor.
     */
    public AbsResourceGroup() {
        injectionTargetList = new ArrayList<IInjectionTarget>();
    }

    /**
     * Mapped name.
     */
    private String mappedName = null;
    
    /**
     * Lookup name.
     */
    private String lookupName = null;

    /**
     * Gets the mapped name.
     * @return the mapped name
     */
    public String getMappedName() {
        return mappedName;
    }

    /**
     * Set the mapped name.
     * @param mappedName the given mapped name.
     */
    public void setMappedName(final String mappedName) {
        this.mappedName = mappedName;
    }

    /**
     * @return the injectionTarget list
     */
    public List<IInjectionTarget> getInjectionTargetList() {
        return injectionTargetList;
    }

    /**
     * Adds the igiven njection target value.
     * @param injectionTarget value of injectionTarget element
     */
    public void addInjectionTarget(final IInjectionTarget injectionTarget) {
        injectionTargetList.add(injectionTarget);
    }
    
    /**
     * @return lookup.
     */
    public String getLookupName() {
        return lookupName;
    }

    /**
     * Sets lookup the lookup Name.
     * @param lookupName the given lookup.
     */
    public void setLookupName(final String lookupName) {
        this.lookupName = lookupName;
    }
}
