/*
 * EasyBeans
 * Copyright (C) 2012 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: DataSource.java 6280 2012-08-30 09:52:43Z albertil $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.ee.metadata.common.impl.xml.struct;

import org.ow2.util.ee.metadata.common.api.xml.struct.IDataSource;

/**
 * Class representing data-source elements used in Java EE components.
 * @author Loic Albertin
 */
public class DataSource implements IDataSource {
    private static final long serialVersionUID = 756107675096711732L;
    /**
     * JNDI name by which the data source name will be registered.
     */
    private String name = null;

    /**
     * DataSource implementation class className.
     */
    private String className = null;

    /**
     * Description of the data source.
     */
    private String description = null;

    /**
     * A JDBC url. If the url property is specified along with other standard DataSource properties such as
     * serverName and
     * portNumber, the more specific properties will take precedence and the url will be ignored
     */
    private String url = null;

    /**
     * User name for connection authentications
     */
    private String user = null;

    /**
     * password for connection authentications
     */
    private String password = null;

    /**
     * Name of a database on a server
     */
    private String databaseName = null;

    /**
     * Port number where a server is listening for requests
     */
    private Integer portNumber = null;

    /**
     * Database server name
     */
    private String serverName = null;

    /**
     * Isolation level for connections.
     */
    private Integer isolationLevel = null;

    /**
     * Indicates whether a connection is transactional or not.
     */
    private Boolean transactional = null;

    /**
     * Number of connections that should be created when a connection pool is initialized
     */
    private Integer initialPoolSize = null;

    /**
     * Maximum number of connections that should be concurrently allocated for a connection pool
     */
    private Integer maxPoolSize = null;

    /**
     * Minimum number of connections that should be allocated for a connection pool
     */
    private Integer minPoolSize = null;

    /**
     * The number of seconds that a physical connection should remain unused in the pool before the connection is
     * closed for a
     * connection pool
     */
    private Integer maxIdleTime = null;

    /**
     * The total number of statements that a connection pool should keep open. A value of 0 indicates that the
     * caching of
     * statements is disabled for a connection pool.
     */
    Integer maxStatements = null;

    /**
     * Used to specify vendor specific properties and less commonly used DataSource properties.
     */
    private String[] properties = null;

    /**
     * The maximum time in seconds that this data source will wait while attempting to connect to a database. A value
     * of 0
     * specifies that the timeout is the = system timeout if there is one, otherwise it specifies that there is no
     * timeout
     */
    private Integer loginTimeout = null;


    public String getClassName() {
        return className;
    }

    public void setClassName(String className) {
        this.className = className;
    }

    public String getDatabaseName() {
        return databaseName;
    }

    public void setDatabaseName(String databaseName) {
        this.databaseName = databaseName;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public Integer getInitialPoolSize() {
        return initialPoolSize;
    }

    public void setInitialPoolSize(Integer initialPoolSize) {
        this.initialPoolSize = initialPoolSize;
    }

    public Integer getIsolationLevel() {
        return isolationLevel;
    }

    public void setIsolationLevel(Integer isolationLevel) {
        this.isolationLevel = isolationLevel;
    }

    public Integer getLoginTimeout() {
        return loginTimeout;
    }

    public void setLoginTimeout(Integer loginTimeout) {
        this.loginTimeout = loginTimeout;
    }

    public Integer getMaxIdleTime() {
        return maxIdleTime;
    }

    public void setMaxIdleTime(Integer maxIdleTime) {
        this.maxIdleTime = maxIdleTime;
    }

    public Integer getMaxPoolSize() {
        return maxPoolSize;
    }

    public void setMaxPoolSize(Integer maxPoolSize) {
        this.maxPoolSize = maxPoolSize;
    }

    public Integer getMaxStatements() {
        return maxStatements;
    }

    public void setMaxStatements(Integer maxStatements) {
        this.maxStatements = maxStatements;
    }

    public Integer getMinPoolSize() {
        return minPoolSize;
    }

    public void setMinPoolSize(Integer minPoolSize) {
        this.minPoolSize = minPoolSize;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getPassword() {
        return password;
    }

    public void setPassword(String password) {
        this.password = password;
    }

    public Integer getPortNumber() {
        return portNumber;
    }

    public void setPortNumber(Integer portNumber) {
        this.portNumber = portNumber;
    }

    public String[] getProperties() {
        return properties;
    }

    public void setProperties(String[] properties) {
        this.properties = properties;
    }

    public String getServerName() {
        return serverName;
    }

    public void setServerName(String serverName) {
        this.serverName = serverName;
    }

    public Boolean isTransactional() {
        return transactional;
    }

    public void setTransactional(Boolean transactional) {
        this.transactional = transactional;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getUser() {
        return user;
    }

    public void setUser(String user) {
        this.user = user;
    }
}
